﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Reflection;
using Syncfusion.Pdf.Parsing;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.Storage;
using Windows.Storage.Pickers;
using Windows.Storage.Streams;
using Windows.System;
using Windows.UI.Popups;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;
//using Syncfusion.Windows.PdfViewer;
using Syncfusion.Pdf;
using Syncfusion.Pdf.Graphics;
using Syncfusion.Pdf.Interactive;
using System.Drawing;

// The Blank Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=234238

namespace PDFViewerWintRT
{
    /// <summary>
    /// An empty page that can be used on its own or navigated to within a Frame.
    /// </summary>
    public sealed partial class MainPage : Page
    {
        PdfLoadedDocument ldoc;
        Assembly assembly;
        private bool m_canvasEnable = false;
        PdfDocument doc;
        public MainPage()
        {
            this.InitializeComponent();
            this.DataContext = pdfViewer;
            assembly = typeof(MainPage).GetTypeInfo().Assembly;
            doc = new PdfDocument();
        }

        public View view { get; set; }
        /// <summary>
        /// Invoked when this page is about to be displayed in a Frame.
        /// </summary>
        /// <param name="e">Event data that describes how this page was reached.  The Parameter
        /// property is typically used to configure the page.</param>
        protected override void OnNavigatedTo(NavigationEventArgs e)
        {

        }
        public PdfLoadedDocument loaded
        {
            get
            {
                return ldoc;
            }
            set
            {
                ldoc = value;
            }
        }
        private void PageLoaded(object sender, RoutedEventArgs e)
        {
            view = new View();
            Stream fileStream = assembly.GetManifestResourceStream("PDFViewerWintRT.Assets.Pdf.CorporateBrochure.pdf");
            byte[] buffer = new byte[fileStream.Length];
            fileStream.Read(buffer, 0, buffer.Length);
            ldoc = new PdfLoadedDocument(buffer);
            pdfViewer.LoadDocument(ldoc);
        }

        async private void BtnOpen_Click_1(object sender, RoutedEventArgs e)
        {
            
            var picker = new FileOpenPicker();
            picker.SuggestedStartLocation = PickerLocationId.DocumentsLibrary;
            picker.ViewMode = PickerViewMode.List;
            picker.FileTypeFilter.Add(".pdf");
            var file = await picker.PickSingleFileAsync();
            if (file == null) return;
            var stream = await file.OpenAsync(Windows.Storage.FileAccessMode.Read);
            Stream fileStream = stream.AsStreamForRead();
            byte[] buffer = new byte[fileStream.Length];
            fileStream.Read(buffer, 0, buffer.Length);
            ldoc = new PdfLoadedDocument(buffer);
            rotation = PdfPageRotateAngle.RotateAngle0;
            pdfViewer.LoadDocument(ldoc);
        }
        #region "Value Setting Methods"
        //scrollViewer that you defined produce inconvenience during drawing and so we used stack panel 
        //as stack_canvas in that we kept your ink canvas to avoid unwanted scrolling
        private void SetZIndexValues()
        {
            if (m_canvasEnable)
            {
                //make sure the canvas is upfront
                Canvas.SetZIndex(pdfViewer, 1);
                Canvas.SetZIndex(stack_canvas, 2);
            }
            else
            {
                Canvas.SetZIndex(pdfViewer, 2);
                Canvas.SetZIndex(stack_canvas, 1);
            }
        }

        private void GotoPopUpButton_Click(object sender, RoutedEventArgs e)
        {
            ZoomPopUp.IsOpen = false;
            ViewModePopUp.IsOpen = false;
            if (GotoPagePopUp.IsOpen)
            {
                GotoPagePopUp.IsOpen = false;
            }
            else
            {
                GotoPagePopUp.IsOpen = true;
            }
        }

        private void PageDextTxtBox_KeyDown(object sender, KeyRoutedEventArgs e)
        {
            int destPage = 0;
            bool result = int.TryParse(PageDextTxtBox.Text, out destPage);
            if (e.Key == VirtualKey.Enter && result)
            {
                pdfViewer.GotoPage(destPage);
                PageDextTxtBox.Text = string.Empty;
            }
        }

        private void PageDextTxtBox_GotFocus(object sender, RoutedEventArgs e)
        {
            PageDextTxtBox.SelectAll();
        }

        private void ZoomValue_KeyDown(object sender, TappedRoutedEventArgs e)
        {
            int zoomValue = 0;
            bool result = int.TryParse(PageDextTxtBox.Text, out zoomValue);
            if (zoomValue >= 100 || zoomValue <= 300)
            {
                pdfViewer.ZoomTo(zoomValue);
            }
        }

        private void ClosePopUp(object sender, TappedRoutedEventArgs e)
        {
            GotoPagePopUp.IsOpen = false;
            PageDextTxtBox.Text = string.Empty;
        }

        private void ZoomValue_KeyDown_1(object sender, KeyRoutedEventArgs e)
        {
            int zoomValue = 0;
            bool result = int.TryParse(ZoomValue.Text, out zoomValue);
            if (e.Key == VirtualKey.Enter && result)
                if (zoomValue >= 100 || zoomValue <= 300)
                {
                    pdfViewer.ZoomTo(zoomValue);
                }
        }

        private void Zoom_BtnClick(object sender, RoutedEventArgs e)
        {
            int zoomValue = 0;
            bool result = int.TryParse(ZoomValue.Text, out zoomValue);

            if (zoomValue >= 100 || zoomValue <= 300)
            {
                pdfViewer.ZoomTo(zoomValue);
            }
        }

        private void ZoomPopUp_ButtonClick(object sender, RoutedEventArgs e)
        {
            GotoPagePopUp.IsOpen = false;
            ViewModePopUp.IsOpen = false;
            if (ZoomPopUp.IsOpen)
            {
                ZoomPopUp.IsOpen = false;
            }
            else
            {
                ZoomPopUp.IsOpen = true;
            }
        }

        private void ZoomValue_GotFocus(object sender, RoutedEventArgs e)
        {
            ZoomValue.SelectAll();
        }

        private void ViewModePopUp_ButtonClick(object sender, RoutedEventArgs e)
        {
            ZoomPopUp.IsOpen = false;
            GotoPagePopUp.IsOpen = false;
            if (ViewModePopUp.IsOpen)
            {
                ViewModePopUp.IsOpen = false;
            }
            else
            {
                ViewModePopUp.IsOpen = true;
            }
        }

        private void ViewModeGrid_Loaded(object sender, RoutedEventArgs e)
        {
            if (ViewModeCombo.Items.Count == 0)
            {
                ViewModeCombo.Items.Add(Syncfusion.Windows.PdfViewer.PageViewMode.FitWidth);
                ViewModeCombo.Items.Add(Syncfusion.Windows.PdfViewer.PageViewMode.Normal);
                ViewModeCombo.Items.Add(Syncfusion.Windows.PdfViewer.PageViewMode.OnePage);
            }
        }

        private void ViewModeSelected_Click(object sender, RoutedEventArgs e)
        {
            object selectedItem = ViewModeCombo.SelectedItem;
            if (selectedItem != null)
                pdfViewer.ViewMode = (Syncfusion.Windows.PdfViewer.PageViewMode)selectedItem;
        }

        internal void LoadDocument(PdfLoadedDocument pdfLoadedDocument)
        {
            pdfLoadedDocument.Save();
        }
        PdfPageRotateAngle rotation;
        async private void clockwise_Click(object sender, RoutedEventArgs e)
        {
            if(doc.Pages==null)
            {
                doc = new PdfDocument();
            }
            doc.PageSettings.Rotate = rotation;
            doc.ImportPageRange(ldoc, 0, ldoc.Pages.Count - 1);
            
            if (doc.PageSettings.Rotate == PdfPageRotateAngle.RotateAngle0)
                doc.PageSettings.Rotate = PdfPageRotateAngle.RotateAngle90;
            else if (doc.PageSettings.Rotate == PdfPageRotateAngle.RotateAngle90)
                doc.PageSettings.Rotate = PdfPageRotateAngle.RotateAngle180;
            else if (doc.PageSettings.Rotate == PdfPageRotateAngle.RotateAngle180)
                doc.PageSettings.Rotate = PdfPageRotateAngle.RotateAngle270;
            else if (doc.PageSettings.Rotate == PdfPageRotateAngle.RotateAngle270)
                doc.PageSettings.Rotate = PdfPageRotateAngle.RotateAngle0;
            rotation = doc.PageSettings.Rotate;
            MemoryStream ms = new MemoryStream();

            doc.Save(ms);
            byte[] buffer = new byte[ms.Length];
            ms.Read(buffer, 0, buffer.Length);
            PdfLoadedDocument ldocument = new PdfLoadedDocument(ms);
            pdfViewer.LoadDocument(ldocument);
            ldocument.Close(true);
            ms.Dispose();
            doc.Close(true);
        }
    }
}
        #endregion